declare class BasicLoader {
    static blob: {
        createBlobUrl: (code: string, type?: string) => string;
        revokeBlobUrls: (urls: string[]) => void;
    };
    static writeModuleUrl(filepath: string, moduleUrl: string): void;
    static requestFile(url: string): string;
    static compileBase(rawCode: string, handler: (filepath: string) => unknown): Promise<void>;
    static transform(url: string, rawContent?: string): void;
    static compile(rawCode: string): void;
}

type ImportMap = {
    imports: Record<string, string>;
    scopes: Record<string, Record<string, string>>;
};
interface SetupOptions {
    importmap?: ImportMap;
    entry: string;
    mode: 'ts' | 'react' | 'react17' | 'vue' | 'all';
    vueCompilerPath?: string;
    publicPath?: string;
    sourceMap?: Record<string, string>;
    loaders?: (typeof BasicLoader)[];
}

declare class ScriptLoader extends BasicLoader {
    static getDepsMapByCode(rawCode: string): Promise<void>;
    static transformBabel(rawContent: string, filepath: string): any;
    static transform(url: string, rawContent?: string): {
        moduleUrl: string;
        code: any;
    };
    static compile(rawCode: string): Promise<void>;
}

declare class StyleLoader extends BasicLoader {
    static transform(url: string, rawContent?: string): {
        code: string;
        moduleUrl: string;
    };
    static compile(rawCode: string): void;
}

declare class ImageLoader extends BasicLoader {
    static compile(rawCode: string): void;
}

declare class HTMLLoader extends BasicLoader {
    static transform(url: string, rawContent?: string): {
        code: string;
        moduleUrl: string;
    };
    static compile(rawCode: string): void;
}

declare class JsonLoader extends BasicLoader {
    static transform(url: string, rawContent?: string): {
        code: string;
        moduleUrl: string;
    };
    static compile(rawCode: string): void;
}

declare class YamlLoader extends BasicLoader {
    static transform(url: string, rawContent?: string): {
        code: string;
        moduleUrl: string;
    };
    static compile(rawCode: string): void;
}

declare class VueLoader extends BasicLoader {
    static transform(url: string, rawSfcCode?: string): {
        code: string;
        moduleUrl: string;
    };
    static compile(rawCode: string): Promise<void>;
}

declare const Loaders: Readonly<{
    ScriptLoader: typeof ScriptLoader;
    StyleLoader: typeof StyleLoader;
    ImageLoader: typeof ImageLoader;
    HTMLLoader: typeof HTMLLoader;
    JsonLoader: typeof JsonLoader;
    YamlLoader: typeof YamlLoader;
    VueLoader: typeof VueLoader;
}>;
declare const defaultLoaders: (typeof ScriptLoader | typeof VueLoader | typeof StyleLoader | typeof HTMLLoader | typeof JsonLoader | typeof YamlLoader | typeof ImageLoader)[];

declare const setup: (options: SetupOptions) => Promise<void>;

export { BasicLoader, Loaders, defaultLoaders, setup };
